com web/php: Swap the logic, we only have archives of 2 translations these days: manual/help-translate.php
| From: | Hannes Magnusson | Date: | Fri, 11 Oct 2013 01:05:13 +0000 |
| Subject: | com web/php: Swap the logic, we only have archives of 2 translations these days: manual/help-translate.php | ||
| Groups: | php.webmaster | ||
| Request: | Send a blank email to php-webmaster+get-16829@lists.php.net to get a copy of this message | ||
Commit: e679e88e8dce7e1bf3b663ac4bf6ded5255fac3e
Author: Hannes Magnusson <bjori@mongodb.com> Thu, 10 Oct 2013 18:05:13 -0700
Parents: 5e50ba68d42df22c41fb2aecb1e3fbf854a7aa1f
Branches: master
Link: http://git.php.net/?p=web/php.git;a=commitdiff;h=e679e88e8dce7e1bf3b663ac4bf6ded5255fac3e
Log:
Swap the logic, we only have archives of 2 translations these days
See also bug #65178
Bugs:
https://bugs.php.net/65178
Changed paths:
M manual/help-translate.php
Diff:
diff --git a/manual/help-translate.php b/manual/help-translate.php
index 5d7f175..f348971 100644
--- a/manual/help-translate.php
+++ b/manual/help-translate.php
@@ -25,13 +25,13 @@ The following list of languages already contain SVN modules, and will show up on
<h3>Inactive languages already in SVN</h3>
<ul>
<?php
-// $none are manuals we don't even have old versions of
-$none = array('ar');
+// $archived are manuals we have old versions of
+$archived = array('da', 'kr');
foreach ($INACTIVE_ONLINE_LANGUAGES as $cc => $lang) {
- $link = '<a href="http://docs.php.net/manual/'. $cc
.'">archive</a>';
- if (in_array($cc, $none)) {
- $link = 'no archive';
+ $link = 'no archive';
+ if (in_array($cc, $archived)) {
+ $link = '<a href="http://docs.php.net/manual/'. $cc
.'">archive</a>';
}
echo '<li>', $lang, ' : (', $link, ')</li>';
}